#ifndef PX_CONSTANTS_H
#define PX_CONSTANTS_H

//#include <string>

// a place to put global constants so they do not have to be redefined

const long double PI = 3.1415926535897932384626433832795L;
const long double E = 2.718281828459045;
const double EPSILON = 1e-7;

#endif /* PX_CONSTANTS_H */
